"use strict";

exports.__esModule = true;
exports.default = void 0;

var _isObject = _interopRequireDefault(require("./isObject"));

var _isArrayish = _interopRequireDefault(require("./isArrayish"));

var _isStrictEqual = _interopRequireDefault(require("./isStrictEqual"));

var _isSameType = _interopRequireDefault(require("./isSameType"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Checks if two provided values are deeply equal.
 * If Objects or Arrays (or Array-like values) are provided, they are inspected recursively.
 * Primitive values are checked to see if they are stricly equal (ie triple equals; no type coercion).
 *
 * @function
 * @name isEqual
 * @param {*} firstVal A value which may be null, undefined, a JavaScript primitive value, an array of values, an array-like value, or an object
 * @param {*} secondVal A value which may be null, undefined, a JavaScript
 * @returns {boolean} Whether or not the two values are deeply equal
 */
function isEqual(firstVal, secondVal) {
  if ((0, _isStrictEqual.default)(firstVal, secondVal)) return true;
  if (!(0, _isSameType.default)(firstVal, secondVal)) return false;

  if (Array.isArray(firstVal) && Array.isArray(secondVal)) {
    var valLen = firstVal.length;
    if (valLen !== secondVal.length) return false;

    for (var i = 0; i < valLen; i++) {
      if (!isEqual(firstVal[i], secondVal[i])) return false;
    }

    return true;
  }

  if ((0, _isObject.default)(firstVal)) {
    var firstKeys = Object.keys(firstVal);
    var secondKeys = Object.keys(secondVal);
    return firstKeys.length === secondKeys.length && firstKeys.every(function (key) {
      return isEqual(firstVal[key], secondVal[key]);
    });
  }

  if ((0, _isArrayish.default)(firstVal)) {
    return firstVal.every(function (v, i) {
      return isEqual(v, secondVal[i]);
    });
  }

  return false;
}

var _default = isEqual;
exports.default = _default;